@@ -19,12 +19,14 @@
 
 #include "renamejob.h"
 
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class RenameJobPrivate : public JobPrivate
 {
@@ -37,10 +39,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 RenameJob::RenameJob(Session *session)
-    : Job(*new RenameJobPrivate(session, "Rename"))
+    : Job(*new RenameJobPrivate(session, i18n("Rename")))
 {
 }
 
@@ -51,8 +53,8 @@ RenameJob::~RenameJob()
 void RenameJob::doStart()
 {
     Q_D(RenameJob);
-    d->sendCommand("RENAME", '\"' + KIMAP2::encodeImapFolderName(d->sourceMailBox.toUtf8()) +
-            "\" \"" + KIMAP2::encodeImapFolderName(d->destinationMailBox.toUtf8()) + '\"');
+    d->tags << d->sessionInternal()->sendCommand("RENAME", '\"' + KIMAP::encodeImapFolderName(d->sourceMailBox.toUtf8()) +
+            "\" \"" + KIMAP::encodeImapFolderName(d->destinationMailBox.toUtf8()) + '\"');
 }
 
 void RenameJob::setSourceMailBox(const QString &mailBox)
